<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Support\Facades\Auth;
use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\CsvImportTrait;
use App\Http\Requests\MassDestroyExportRequest;
use App\Http\Requests\StoreExportRequest;
use App\Http\Requests\UpdateExportRequest;
use App\Models\ContainerSize;
use App\Models\Export;
use App\Models\Port;
use App\Models\Seal;
use App\Models\Team;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use DB;

class ExportController extends Controller
{
    use CsvImportTrait;

    public function index()
    {
        $userid = Auth::user()->id;
        abort_if(Gate::denies('export_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if($user = Auth::user()->roles[0]->pivot->role_id == 1){
        $exports = Export::with(['destination_custom', 'eseal', 'container_size', 'team'])->get();
        }else{
            $exports = Export::with(['destination_custom', 'eseal', 'container_size', 'team'])->where('exporter_id' , $userid )->get();
        }

        $ports = Port::get();

        $seals = Seal::get();

        $container_sizes = ContainerSize::get();

        $teams = Team::get();

        return view('admin.exports.index', compact('exports', 'ports', 'seals', 'container_sizes', 'teams'));
    }

    public function create()
    {
        $userid = Auth::user()->id;
        abort_if(Gate::denies('export_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $destination_customs = Port::pluck('port_name', 'id')->prepend(trans('global.pleaseSelect'), '');

       if($user = Auth::user()->roles[0]->pivot->role_id == 1){

        $eseals = Seal::pluck('sn', 'id')->prepend(trans('global.pleaseSelect'), '');
        }else{
        $eseals = Seal::where('exporter_id' , $userid )->where('used' , 0 )->pluck('sn', 'id')->prepend(trans('global.pleaseSelect'), '');
         }

        $container_sizes = ContainerSize::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.exports.create', compact('destination_customs', 'eseals', 'container_sizes'));
    }

    public function store(StoreExportRequest $request)
    {
        $userid = Auth::user()->id;
        $eseal_id =   $request->eseal_id;
        $useddate = date('Y-m-d h:i:s', time());
        $export = Export::create(array_merge($request->all(), ['exporter_id' =>  $userid])); 
        $seals = \DB::table('seals')->where('id' , $eseal_id)->update(['used' => 1,'used_time' => $useddate]); 

        return redirect()->route('admin.exports.index');
    }

    public function edit(Export $export)
    {
        abort_if(Gate::denies('export_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $destination_customs = Port::pluck('port_name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $eseals = Seal::pluck('sn', 'id')->prepend(trans('global.pleaseSelect'), '');

        $container_sizes = ContainerSize::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $export->load('destination_custom', 'eseal', 'container_size', 'team');

        return view('admin.exports.edit', compact('destination_customs', 'eseals', 'container_sizes', 'export'));
    }

    public function update(UpdateExportRequest $request, Export $export)
    {

        $userid = Auth::user()->id;
        $updatearray =  array_merge($request->all(), ['exporter_id' => $userid]);
        $export->update($updatearray);

        return redirect()->route('admin.exports.index');
    }

    public function show(Export $export)
    {
        abort_if(Gate::denies('export_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $export->load('destination_custom', 'eseal', 'container_size', 'team');

        return view('admin.exports.show', compact('export'));
    }

    public function destroy(Export $export)
    {
        abort_if(Gate::denies('export_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $export->delete();

        return back();
    }

    public function massDestroy(MassDestroyExportRequest $request)
    {
        Export::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }

    public function pdfexports($id)
    {
        $exports = Export::with(['destination_custom', 'eseal', 'container_size', 'team'])->where('id',$id)->first();

        return view('admin.exports.pdfview', compact('exports'));
    }
}
