<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\CsvImportTrait;
use App\Http\Requests\MassDestroySuplierRequest;
use App\Http\Requests\StoreSuplierRequest;
use App\Http\Requests\UpdateSuplierRequest;
use App\Models\Suplier;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class SupliersController extends Controller
{
    use CsvImportTrait;

    public function index()
    {
        abort_if(Gate::denies('suplier_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $supliers = Suplier::all();

        return view('admin.supliers.index', compact('supliers'));
    }

    public function create()
    {
        abort_if(Gate::denies('suplier_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.supliers.create');
    }

    public function store(StoreSuplierRequest $request)
    {
        $suplier = Suplier::create($request->all());

        return redirect()->route('admin.supliers.index');
    }

    public function edit(Suplier $suplier)
    {
        abort_if(Gate::denies('suplier_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.supliers.edit', compact('suplier'));
    }

    public function update(UpdateSuplierRequest $request, Suplier $suplier)
    {
        $suplier->update($request->all());

        return redirect()->route('admin.supliers.index');
    }

    public function show(Suplier $suplier)
    {
        abort_if(Gate::denies('suplier_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.supliers.show', compact('suplier'));
    }

    public function destroy(Suplier $suplier)
    {
        abort_if(Gate::denies('suplier_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $suplier->delete();

        return back();
    }

    public function massDestroy(MassDestroySuplierRequest $request)
    {
        Suplier::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
