<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Support\Facades\Auth;
use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\MediaUploadingTrait;
use App\Http\Requests\MassDestroyUserRequest;
use App\Http\Requests\StoreUserRequest;
use App\Http\Requests\UpdateUserRequest;
use App\Models\Branch;
use App\Models\City;
use App\Models\RegisteredExporter;
use App\Models\Role;
use App\Models\State;
use App\Models\Team;
use App\Models\User;
use Gate;
use Illuminate\Http\Request;
use Spatie\MediaLibrary\MediaCollections\Models\Media;
use Symfony\Component\HttpFoundation\Response;
use DB;

class UsersController extends Controller
{
    use MediaUploadingTrait;

    public function index()
    {
         $userId = Auth::id();
       $query = DB::table('role_user')->where('user_id', '=', $userId)->first();

        abort_if(Gate::denies('user_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');
       if($query->role_id == '3')
         {
        $users = User::with(['roles', 'exporter', 'state', 'city', 'branch', 'team', 'media'])->where('exporter_id',$userId)->get();
        }else if($query->role_id == '4'){
         $users = User::with(['roles', 'exporter', 'state', 'city', 'branch', 'team', 'media'])->where('exporter_id',$userId)->get(); 
        }else{
           $users = User::with(['roles', 'exporter', 'state', 'city', 'branch', 'team', 'media'])->get(); 
        }

        $roles = Role::get();

        $registered_exporters = RegisteredExporter::get();

        $states = State::get();

        $cities = City::get();

        $branches = Branch::get();

        $teams = Team::get();




   
    if($query->role_id == '3')
      {
         return view('admin.users.viewuser', compact('users', 'roles', 'registered_exporters', 'states', 'cities', 'branches', 'teams','userId'));
     }else{
        return view('admin.users.index', compact('users', 'roles', 'registered_exporters', 'states', 'cities', 'branches', 'teams'));
     }

        // return view('admin.users.index', compact('users', 'roles', 'registered_exporters', 'states', 'cities', 'branches', 'teams'));
    }

    public function create()
    {
         $userId = Auth::id();
         $query = DB::table('role_user')->where('user_id', '=', $userId)->first();
        abort_if(Gate::denies('user_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $roles = Role::pluck('title', 'id');

        $exporters = RegisteredExporter::pluck('import_export_code', 'id')->prepend(trans('global.pleaseSelect'), '');

        $states = State::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $cities = City::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $branches = Branch::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $teams = Team::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');
    if($query->role_id == '3')
    {
        return view('admin.users.user', compact('roles', 'exporters', 'states', 'cities', 'branches', 'teams','userId'));
    }else{
    return view('admin.users.create', compact('roles', 'exporters', 'states', 'cities', 'branches', 'teams'));
    }

    }

    public function store(StoreUserRequest $request)
    {
        return $request->all();
        $user = User::create($request->all());
        $user->roles()->sync($request->input('roles', []));
        if ($request->input('gst', false)) {
            $user->addMedia(storage_path('tmp/uploads/' . basename($request->input('gst'))))->toMediaCollection('gst');
        }

        if ($request->input('iec', false)) {
            $user->addMedia(storage_path('tmp/uploads/' . basename($request->input('iec'))))->toMediaCollection('iec');
        }

        if ($request->input('pan', false)) {
            $user->addMedia(storage_path('tmp/uploads/' . basename($request->input('pan'))))->toMediaCollection('pan');
        }

        if ($request->input('cancelled_cheque', false)) {
            $user->addMedia(storage_path('tmp/uploads/' . basename($request->input('cancelled_cheque'))))->toMediaCollection('cancelled_cheque');
        }

        if ($request->input('self_certification', false)) {
            $user->addMedia(storage_path('tmp/uploads/' . basename($request->input('self_certification'))))->toMediaCollection('self_certification');
        }

        if ($media = $request->input('ck-media', false)) {
            Media::whereIn('id', $media)->update(['model_id' => $user->id]);
        }

        return redirect()->route('admin.users.index');
    }

    public function edit(User $user)
    {
        $userId = Auth::id();
         $query = DB::table('role_user')->where('user_id', '=', $userId)->first();
         $role_id = $query->role_id;
        abort_if(Gate::denies('user_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $roles = Role::pluck('title', 'id');

        $exporters = RegisteredExporter::pluck('import_export_code', 'id')->prepend(trans('global.pleaseSelect'), '');

        $states = State::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $cities = City::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $branches = Branch::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $teams = Team::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $user->load('roles', 'exporter', 'state', 'city', 'branch', 'team');

        return view('admin.users.edit', compact('roles', 'exporters', 'states', 'cities', 'branches', 'teams', 'user','role_id','userId'));
    }

    public function update(UpdateUserRequest $request, User $user)
    {
        $user->update($request->all());
        $user->roles()->sync($request->input('roles', []));
        if ($request->input('gst', false)) {
            if (!$user->gst || $request->input('gst') !== $user->gst->file_name) {
                if ($user->gst) {
                    $user->gst->delete();
                }
                $user->addMedia(storage_path('tmp/uploads/' . basename($request->input('gst'))))->toMediaCollection('gst');
            }
        } elseif ($user->gst) {
            $user->gst->delete();
        }

        if ($request->input('iec', false)) {
            if (!$user->iec || $request->input('iec') !== $user->iec->file_name) {
                if ($user->iec) {
                    $user->iec->delete();
                }
                $user->addMedia(storage_path('tmp/uploads/' . basename($request->input('iec'))))->toMediaCollection('iec');
            }
        } elseif ($user->iec) {
            $user->iec->delete();
        }

        if ($request->input('pan', false)) {
            if (!$user->pan || $request->input('pan') !== $user->pan->file_name) {
                if ($user->pan) {
                    $user->pan->delete();
                }
                $user->addMedia(storage_path('tmp/uploads/' . basename($request->input('pan'))))->toMediaCollection('pan');
            }
        } elseif ($user->pan) {
            $user->pan->delete();
        }

        if ($request->input('cancelled_cheque', false)) {
            if (!$user->cancelled_cheque || $request->input('cancelled_cheque') !== $user->cancelled_cheque->file_name) {
                if ($user->cancelled_cheque) {
                    $user->cancelled_cheque->delete();
                }
                $user->addMedia(storage_path('tmp/uploads/' . basename($request->input('cancelled_cheque'))))->toMediaCollection('cancelled_cheque');
            }
        } elseif ($user->cancelled_cheque) {
            $user->cancelled_cheque->delete();
        }

        if ($request->input('self_certification', false)) {
            if (!$user->self_certification || $request->input('self_certification') !== $user->self_certification->file_name) {
                if ($user->self_certification) {
                    $user->self_certification->delete();
                }
                $user->addMedia(storage_path('tmp/uploads/' . basename($request->input('self_certification'))))->toMediaCollection('self_certification');
            }
        } elseif ($user->self_certification) {
            $user->self_certification->delete();
        }

        return redirect()->route('admin.users.index');
    }

    public function show(User $user)
    {
        abort_if(Gate::denies('user_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $user->load('roles', 'exporter', 'state', 'city', 'branch', 'team', 'userUserAlerts');

        return view('admin.users.show', compact('user'));
    }

    public function destroy(User $user)
    {
        abort_if(Gate::denies('user_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $user->delete();

        return back();
    }

    public function massDestroy(MassDestroyUserRequest $request)
    {
        User::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }

    public function storeCKEditorImages(Request $request)
    {
        abort_if(Gate::denies('user_create') && Gate::denies('user_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $model         = new User();
        $model->id     = $request->input('crud_id', 0);
        $model->exists = true;
        $media         = $model->addMediaFromRequest('upload')->toMediaCollection('ck-media');

        return response()->json(['id' => $media->id, 'url' => $media->getUrl()], Response::HTTP_CREATED);
    }

     public function AddBranch()
    {
        $userId = Auth::id();

        $roles = Role::pluck('title', 'id');

        $exporters = RegisteredExporter::pluck('import_export_code', 'id')->prepend(trans('global.pleaseSelect'), '');

        $states = State::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $cities = City::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $branches= DB::table('user_branches')->where('user_id' , $userId)->latest('id')->first();
        $branch_id =  $branches->branch_id;
        $branch = DB::table('branches')->where('id', '>', $branch_id)->first();

        $teams = Team::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.users.addbranch', compact('roles', 'exporters', 'states', 'cities', 'teams','branch','userId'));
    }

    public function postbranch(Request $request)
    {
     $user = DB::table('user_branches')->insert(request()->except(['_token']));
     return redirect()->route('admin.users.index');
       //return redirect('admin.users.users');
    }
}
