<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreContainerSizeRequest;
use App\Http\Requests\UpdateContainerSizeRequest;
use App\Http\Resources\Admin\ContainerSizeResource;
use App\Models\ContainerSize;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class ContainerSizeApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('container_size_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new ContainerSizeResource(ContainerSize::all());
    }

    public function store(StoreContainerSizeRequest $request)
    {
        $containerSize = ContainerSize::create($request->all());

        return (new ContainerSizeResource($containerSize))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(ContainerSize $containerSize)
    {
        abort_if(Gate::denies('container_size_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new ContainerSizeResource($containerSize);
    }

    public function update(UpdateContainerSizeRequest $request, ContainerSize $containerSize)
    {
        $containerSize->update($request->all());

        return (new ContainerSizeResource($containerSize))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(ContainerSize $containerSize)
    {
        abort_if(Gate::denies('container_size_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $containerSize->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
