<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreEsealtrackingRequest;
use App\Http\Requests\UpdateEsealtrackingRequest;
use App\Http\Resources\Admin\EsealtrackingResource;
use App\Models\Esealtracking;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class EsealtrackingApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('esealtracking_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new EsealtrackingResource(Esealtracking::all());
    }

    public function store(StoreEsealtrackingRequest $request)
    {
        $esealtracking = Esealtracking::create($request->all());

        return (new EsealtrackingResource($esealtracking))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(Esealtracking $esealtracking)
    {
        abort_if(Gate::denies('esealtracking_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new EsealtrackingResource($esealtracking);
    }

    public function update(UpdateEsealtrackingRequest $request, Esealtracking $esealtracking)
    {
        $esealtracking->update($request->all());

        return (new EsealtrackingResource($esealtracking))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(Esealtracking $esealtracking)
    {
        abort_if(Gate::denies('esealtracking_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $esealtracking->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
