<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreExportRequest;
use App\Http\Requests\UpdateExportRequest;
use App\Http\Resources\Admin\ExportResource;
use App\Models\Export;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class ExportApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('export_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new ExportResource(Export::with(['destination_custom', 'eseal', 'container_size', 'team'])->get());
    }

    public function store(StoreExportRequest $request)
    {
        $export = Export::create($request->all());

        return (new ExportResource($export))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(Export $export)
    {
        abort_if(Gate::denies('export_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new ExportResource($export->load(['destination_custom', 'eseal', 'container_size', 'team']));
    }

    public function update(UpdateExportRequest $request, Export $export)
    {
        $export->update($request->all());

        return (new ExportResource($export))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(Export $export)
    {
        abort_if(Gate::denies('export_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $export->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
