<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreSealRequest;
use App\Http\Requests\UpdateSealRequest;
use App\Http\Resources\Admin\SealResource;
use App\Models\Seal;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class SealsApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('seal_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new SealResource(Seal::with(['supplier', 'team'])->get());
    }

    public function store(StoreSealRequest $request)
    {
        $seal = Seal::create($request->all());

        return (new SealResource($seal))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(Seal $seal)
    {
        abort_if(Gate::denies('seal_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new SealResource($seal->load(['supplier', 'team']));
    }

    public function update(UpdateSealRequest $request, Seal $seal)
    {
        $seal->update($request->all());

        return (new SealResource($seal))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(Seal $seal)
    {
        abort_if(Gate::denies('seal_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $seal->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
