<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\MediaUploadingTrait;
use App\Http\Requests\StoreUserRequest;
use App\Http\Requests\UpdateUserRequest;
use App\Http\Resources\Admin\UserResource;
use App\Models\User;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class UsersApiController extends Controller
{
    use MediaUploadingTrait;

    public function index()
    {
        abort_if(Gate::denies('user_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new UserResource(User::with(['roles', 'exporter', 'state', 'city', 'branch', 'team'])->get());
    }

    public function store(StoreUserRequest $request)
    {
        $user = User::create($request->all());
        $user->roles()->sync($request->input('roles', []));
        if ($request->input('gst', false)) {
            $user->addMedia(storage_path('tmp/uploads/' . basename($request->input('gst'))))->toMediaCollection('gst');
        }

        if ($request->input('iec', false)) {
            $user->addMedia(storage_path('tmp/uploads/' . basename($request->input('iec'))))->toMediaCollection('iec');
        }

        if ($request->input('pan', false)) {
            $user->addMedia(storage_path('tmp/uploads/' . basename($request->input('pan'))))->toMediaCollection('pan');
        }

        if ($request->input('cancelled_cheque', false)) {
            $user->addMedia(storage_path('tmp/uploads/' . basename($request->input('cancelled_cheque'))))->toMediaCollection('cancelled_cheque');
        }

        if ($request->input('self_certification', false)) {
            $user->addMedia(storage_path('tmp/uploads/' . basename($request->input('self_certification'))))->toMediaCollection('self_certification');
        }

        return (new UserResource($user))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(User $user)
    {
        abort_if(Gate::denies('user_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new UserResource($user->load(['roles', 'exporter', 'state', 'city', 'branch', 'team']));
    }

    public function update(UpdateUserRequest $request, User $user)
    {
        $user->update($request->all());
        $user->roles()->sync($request->input('roles', []));
        if ($request->input('gst', false)) {
            if (!$user->gst || $request->input('gst') !== $user->gst->file_name) {
                if ($user->gst) {
                    $user->gst->delete();
                }
                $user->addMedia(storage_path('tmp/uploads/' . basename($request->input('gst'))))->toMediaCollection('gst');
            }
        } elseif ($user->gst) {
            $user->gst->delete();
        }

        if ($request->input('iec', false)) {
            if (!$user->iec || $request->input('iec') !== $user->iec->file_name) {
                if ($user->iec) {
                    $user->iec->delete();
                }
                $user->addMedia(storage_path('tmp/uploads/' . basename($request->input('iec'))))->toMediaCollection('iec');
            }
        } elseif ($user->iec) {
            $user->iec->delete();
        }

        if ($request->input('pan', false)) {
            if (!$user->pan || $request->input('pan') !== $user->pan->file_name) {
                if ($user->pan) {
                    $user->pan->delete();
                }
                $user->addMedia(storage_path('tmp/uploads/' . basename($request->input('pan'))))->toMediaCollection('pan');
            }
        } elseif ($user->pan) {
            $user->pan->delete();
        }

        if ($request->input('cancelled_cheque', false)) {
            if (!$user->cancelled_cheque || $request->input('cancelled_cheque') !== $user->cancelled_cheque->file_name) {
                if ($user->cancelled_cheque) {
                    $user->cancelled_cheque->delete();
                }
                $user->addMedia(storage_path('tmp/uploads/' . basename($request->input('cancelled_cheque'))))->toMediaCollection('cancelled_cheque');
            }
        } elseif ($user->cancelled_cheque) {
            $user->cancelled_cheque->delete();
        }

        if ($request->input('self_certification', false)) {
            if (!$user->self_certification || $request->input('self_certification') !== $user->self_certification->file_name) {
                if ($user->self_certification) {
                    $user->self_certification->delete();
                }
                $user->addMedia(storage_path('tmp/uploads/' . basename($request->input('self_certification'))))->toMediaCollection('self_certification');
            }
        } elseif ($user->self_certification) {
            $user->self_certification->delete();
        }

        return (new UserResource($user))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(User $user)
    {
        abort_if(Gate::denies('user_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $user->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
