<?php

namespace App\Models;

use \DateTimeInterface;
use App\Traits\MultiTenantModelTrait;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class Order extends Model
{
    use SoftDeletes;
    use MultiTenantModelTrait;
    use HasFactory;

    public const MODE_OF_PAYMENT_SELECT = [
        'Netbanking' => 'Netbanking',
        'Offline'    => 'Offline',
    ];

    public $table = 'orders';

    protected $dates = [
        'expected_date',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'requester_name',
        'requester_contact_no',
        'requester_email',
        'number_of_e_seals',
        'delivery_address',
        'postal_code',
        'state_id',
        'city_id',
        'mode_of_payment',
        'expected_date',
        'created_at',
        'updated_at',
        'deleted_at',
        'team_id',
    ];

    public function state()
    {
        return $this->belongsTo(State::class, 'state_id');
    }

    public function city()
    {
        return $this->belongsTo(City::class, 'city_id');
    }

    public function getExpectedDateAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setExpectedDateAttribute($value)
    {
        $this->attributes['expected_date'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function team()
    {
        return $this->belongsTo(Team::class, 'team_id');
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
