@extends('layouts.admin')
@section('content')

<div class="card">
    <div class="card-header">
        {{ trans('global.create') }} {{ trans('cruds.order.title_singular') }}
    </div>

    <div class="card-body">
        <form method="POST" action="{{ route("admin.orders.store") }}" enctype="multipart/form-data">
            @csrf
            <div class="form-group">
                <label class="required" for="requester_name">{{ trans('cruds.order.fields.requester_name') }}</label>
                <input class="form-control {{ $errors->has('requester_name') ? 'is-invalid' : '' }}" type="text" name="requester_name" id="requester_name" value="{{ old('requester_name', '') }}" required>
                @if($errors->has('requester_name'))
                    <div class="invalid-feedback">
                        {{ $errors->first('requester_name') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.order.fields.requester_name_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="requester_contact_no">{{ trans('cruds.order.fields.requester_contact_no') }}</label>
                <input class="form-control {{ $errors->has('requester_contact_no') ? 'is-invalid' : '' }}" type="text" name="requester_contact_no" id="requester_contact_no" value="{{ old('requester_contact_no', '') }}" required>
                @if($errors->has('requester_contact_no'))
                    <div class="invalid-feedback">
                        {{ $errors->first('requester_contact_no') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.order.fields.requester_contact_no_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="requester_email">{{ trans('cruds.order.fields.requester_email') }}</label>
                <input class="form-control {{ $errors->has('requester_email') ? 'is-invalid' : '' }}" type="email" name="requester_email" id="requester_email" value="{{ old('requester_email') }}">
                @if($errors->has('requester_email'))
                    <div class="invalid-feedback">
                        {{ $errors->first('requester_email') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.order.fields.requester_email_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="number_of_e_seals">{{ trans('cruds.order.fields.number_of_e_seals') }}</label>
                <input class="form-control {{ $errors->has('number_of_e_seals') ? 'is-invalid' : '' }}" type="text" name="number_of_e_seals" id="number_of_e_seals" value="{{ old('number_of_e_seals', '') }}" required>
                @if($errors->has('number_of_e_seals'))
                    <div class="invalid-feedback">
                        {{ $errors->first('number_of_e_seals') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.order.fields.number_of_e_seals_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="delivery_address">{{ trans('cruds.order.fields.delivery_address') }}</label>
                <textarea class="form-control {{ $errors->has('delivery_address') ? 'is-invalid' : '' }}" name="delivery_address" id="delivery_address">{{ old('delivery_address') }}</textarea>
                @if($errors->has('delivery_address'))
                    <div class="invalid-feedback">
                        {{ $errors->first('delivery_address') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.order.fields.delivery_address_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="postal_code">{{ trans('cruds.order.fields.postal_code') }}</label>
                <input class="form-control {{ $errors->has('postal_code') ? 'is-invalid' : '' }}" type="text" name="postal_code" id="postal_code" value="{{ old('postal_code', '') }}">
                @if($errors->has('postal_code'))
                    <div class="invalid-feedback">
                        {{ $errors->first('postal_code') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.order.fields.postal_code_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="state_id">{{ trans('cruds.order.fields.state') }}</label>
                <select class="form-control select2 {{ $errors->has('state') ? 'is-invalid' : '' }}" name="state_id" id="state_id" required>
                    @foreach($states as $id => $entry)
                        <option value="{{ $id }}" {{ old('state_id') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('state'))
                    <div class="invalid-feedback">
                        {{ $errors->first('state') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.order.fields.state_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="city_id">{{ trans('cruds.order.fields.city') }}</label>
                <select class="form-control select2 {{ $errors->has('city') ? 'is-invalid' : '' }}" name="city_id" id="city_id" required>
                    @foreach($cities as $id => $entry)
                        <option value="{{ $id }}" {{ old('city_id') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('city'))
                    <div class="invalid-feedback">
                        {{ $errors->first('city') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.order.fields.city_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required">{{ trans('cruds.order.fields.mode_of_payment') }}</label>
                <select class="form-control {{ $errors->has('mode_of_payment') ? 'is-invalid' : '' }}" name="mode_of_payment" id="mode_of_payment" required>
                    <option value disabled {{ old('mode_of_payment', null) === null ? 'selected' : '' }}>{{ trans('global.pleaseSelect') }}</option>
                    @foreach(App\Models\Order::MODE_OF_PAYMENT_SELECT as $key => $label)
                        <option value="{{ $key }}" {{ old('mode_of_payment', '') === (string) $key ? 'selected' : '' }}>{{ $label }}</option>
                    @endforeach
                </select>
                @if($errors->has('mode_of_payment'))
                    <div class="invalid-feedback">
                        {{ $errors->first('mode_of_payment') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.order.fields.mode_of_payment_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="expected_date">{{ trans('cruds.order.fields.expected_date') }}</label>
                <input class="form-control date {{ $errors->has('expected_date') ? 'is-invalid' : '' }}" type="text" name="expected_date" id="expected_date" value="{{ old('expected_date') }}" required>
                @if($errors->has('expected_date'))
                    <div class="invalid-feedback">
                        {{ $errors->first('expected_date') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.order.fields.expected_date_helper') }}</span>
            </div>
            <div class="form-group">
                <button class="btn btn-danger" type="submit">
                    {{ trans('global.save') }}
                </button>
            </div>
        </form>
    </div>
</div>



@endsection