@extends('layouts.admin')
@section('content')

<div class="card">
    <div class="card-header">
        {{ trans('global.edit') }} {{ trans('cruds.seal.title_singular') }}
    </div>

    <div class="card-body">
        <form method="POST" action="{{ route("admin.seals.update", [$seal->id]) }}" enctype="multipart/form-data">
            @method('PUT')
            @csrf
            <div class="form-group">
                <label for="supplier_id">{{ trans('cruds.seal.fields.supplier') }}</label>
                <select class="form-control select2 {{ $errors->has('supplier') ? 'is-invalid' : '' }}" name="supplier_id" id="supplier_id">
                    @foreach($suppliers as $id => $entry)
                        <option value="{{ $id }}" {{ (old('supplier_id') ? old('supplier_id') : $seal->supplier->id ?? '') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('supplier'))
                    <div class="invalid-feedback">
                        {{ $errors->first('supplier') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.seal.fields.supplier_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="sn">{{ trans('cruds.seal.fields.sn') }}</label>
                <input class="form-control {{ $errors->has('sn') ? 'is-invalid' : '' }}" type="text" name="sn" id="sn" value="{{ old('sn', $seal->sn) }}">
                @if($errors->has('sn'))
                    <div class="invalid-feedback">
                        {{ $errors->first('sn') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.seal.fields.sn_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="tid">{{ trans('cruds.seal.fields.tid') }}</label>
                <input class="form-control {{ $errors->has('tid') ? 'is-invalid' : '' }}" type="text" name="tid" id="tid" value="{{ old('tid', $seal->tid) }}">
                @if($errors->has('tid'))
                    <div class="invalid-feedback">
                        {{ $errors->first('tid') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.seal.fields.tid_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="epc">{{ trans('cruds.seal.fields.epc') }}</label>
                <input class="form-control {{ $errors->has('epc') ? 'is-invalid' : '' }}" type="text" name="epc" id="epc" value="{{ old('epc', $seal->epc) }}">
                @if($errors->has('epc'))
                    <div class="invalid-feedback">
                        {{ $errors->first('epc') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.seal.fields.epc_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="ex">{{ trans('cruds.seal.fields.ex') }}</label>
                <input class="form-control {{ $errors->has('ex') ? 'is-invalid' : '' }}" type="text" name="ex" id="ex" value="{{ old('ex', $seal->ex) }}">
                @if($errors->has('ex'))
                    <div class="invalid-feedback">
                        {{ $errors->first('ex') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.seal.fields.ex_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="reach_time">{{ trans('cruds.seal.fields.reach_time') }}</label>
                <input class="form-control timepicker {{ $errors->has('reach_time') ? 'is-invalid' : '' }}" type="text" name="reach_time" id="reach_time" value="{{ old('reach_time', $seal->reach_time) }}">
                @if($errors->has('reach_time'))
                    <div class="invalid-feedback">
                        {{ $errors->first('reach_time') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.seal.fields.reach_time_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="used">{{ trans('cruds.seal.fields.used') }}</label>
                <input class="form-control {{ $errors->has('used') ? 'is-invalid' : '' }}" type="number" name="used" id="used" value="{{ old('used', $seal->used) }}" step="1">
                @if($errors->has('used'))
                    <div class="invalid-feedback">
                        {{ $errors->first('used') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.seal.fields.used_helper') }}</span>
            </div>
            <div class="form-group">
                <button class="btn btn-danger" type="submit">
                    {{ trans('global.save') }}
                </button>
            </div>
        </form>
    </div>
</div>



@endsection